@@ -14,8 +14,13 @@ Including another URLconf
     2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
 """
 from django.contrib import admin
-from django.urls import path
+from django.urls import path, include
+from django.conf.urls import url
+from django.views import generic
+from material.frontend import urls as frontend_urls
 
 urlpatterns = [
     path('admin/', admin.site.urls),
+    path('', include(frontend_urls)),
+    url('^$', generic.RedirectView.as_view(url='./corgy_payroll/'), name="index"),
 ]
